installer

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 24, 2026 License: Apache-2.0 Imports: 13 Imported by: 0

Documentation

Overview

Package installer provides systemd service installation and removal for zerta.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RunInstall

func RunInstall(output io.Writer, args []string) error

RunInstall parses flags and installs zerta as a systemd service.

func RunRemove

func RunRemove(output io.Writer, args []string) error

RunRemove parses flags and removes the zerta systemd service.

Types

type Installer

type Installer struct {
	// contains filtered or unexported fields
}

Installer manages zerta systemd service installation.

Jump to