package
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: Aug 24, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 13
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package installer provides systemd service installation and removal for zerta.
RunInstall parses flags and installs zerta as a systemd service.
RunRemove parses flags and removes the zerta systemd service.
type Installer struct {
}
Installer manages zerta systemd service installation.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.